@@ -1,7 +1,9 @@
+#
+# This file is part of gunicorn released under the MIT license.
+# See the NOTICE for more information.
 
 from pyramid.config import Configurator
 from pyramid.response import Response
-from paste.httpserver import serve
 
 def hello_world(request):
     return Response('Hello world!')
